NegativeSampler
===============

.. currentmodule:: pykeen.sampling

.. autoclass:: NegativeSampler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NegativeSampler.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~NegativeSampler.corrupt_batch
      ~NegativeSampler.get_normalized_name
      ~NegativeSampler.sample

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: corrupt_batch
   .. automethod:: get_normalized_name
   .. automethod:: sample
